pub enum GridCellEncoding {
Grid,
PixelIsArea,
PixelIsPoint,
}Expand description
Interpretation of how each grid sample relates to the cell boundary.
Corresponds to the grid_cell_encoding column of
gpkg_2d_gridded_coverage_ancillary (OGC F.7).
Variants
Grid
"grid-value-is-center" — the value represents the cell centre.
PixelIsArea
"grid-value-is-area" — the value is an average over the entire cell.
PixelIsPoint
"grid-value-is-corner" — the value is located at the cell corner.
Implementations